@@ -66,9 +66,9 @@ function Debugger(sel) {
         this.elt.on('click', '.control-button', this.controlButtonClicked.bind(this));
 
         // events for breakpoints
-        this.elt.on('click', 'tr:not(.unbreakable) td.lineno span',
+        this.elt.on('click', '.code-line:not(.unbreakable) .lineno',
                     this.breakableLineClicked.bind(this));
-        this.elt.on('contextmenu', 'tr:not(.unbreakable) td.lineno',
+        this.elt.on('contextmenu', '.code-line:not(.unbreakable) .lineno',
                     this.breakableLineRightClicked.bind(this));
         this.elt.on('click', '.breakpoint-condition,.action',
                     this.editBreakpointCondition.bind(this));
@@ -171,8 +171,8 @@ function Debugger(sel) {
     // Toggle the breakpoint on a line
     this.breakableLineClicked = function(e) {
         var $elt = $(e.target),
-            filename = $elt.closest('div.tab-pane').attr('data-filename'),
-            lineno = $elt.closest('tr').attr('data-line'),
+            filename = $elt.closest('.program-code').attr('data-filename'),
+            lineno = $elt.closest('.code-line').attr('data-line'),
             bp = this.breakpointManager.get(filename, lineno),
             requestData = { f: filename, l: lineno };
 
@@ -198,8 +198,7 @@ function Debugger(sel) {
         for (line in bp_hash) {
             var condition = bp_hash[line].condition,
                 action = bp_hash[line].action,
-                sel = 'tr:nth-child('+line+')';
-                lineElt = $codeTable.find('tr:nth-child('+line+')');
+                lineElt = $codeTable.find('.code-line:nth-child('+line+')');
 
             lineElt.removeClass('breakpoint conditional-breakpoint inactive-breakpoint bpaction');
             if (condition === '0') {
@@ -223,8 +222,8 @@ function Debugger(sel) {
         this._drawBreakpointMenu($elt);
     };
     this._drawBreakpointMenu = function($elt) {
-        var filename = $elt.closest('div.tab-pane').attr('data-filename'),
-            lineno = $elt.closest('tr').attr('data-line'),
+        var filename = $elt.closest('.program-code').attr('data-filename'),
+            lineno = $elt.closest('.code-line').attr('data-line'),
             bp = this.breakpointManager.get(filename, lineno),
             menu = this.breakpointRightClickMenuTemplate({
                                                     condition: bp.condition,
@@ -390,8 +389,8 @@ function Debugger(sel) {
     // Set the given line "active" (hightlited) and scroll it into view
     // if necessary
     this.setCurrentLineForCodeTable = function(codeTable, line) {
-        codeTable.find('tr').removeClass('active');
-        var activeLine = codeTable.find('tr:nth-child('+line+')').addClass('active');
+        codeTable.find('.active').removeClass('active');
+        var activeLine = codeTable.find('.code-line:nth-child('+line+')').addClass('active');
         if (activeLine.length === 0) {
             // When the program terminates, line is 0 and activeLine.length === 0
             return;
@@ -457,7 +456,7 @@ function Debugger(sel) {
             // same package and filename for the current frame
             if (i === 0) {
                 // just update the currently active line
-                var codeTable = codePane.find('table.program-code');
+                var codeTable = codePane.find('.program-code');
                 this.setCurrentLineForCodeTable(codeTable, line);
 
                 var current = dbg.currentSubAndArgsTemplate({  subroutine: frame.subroutine,
@@ -484,9 +483,17 @@ function Debugger(sel) {
         this.fileManager.loadFile(filename)
             .done(function($elt) {
                 var $copy = $elt.clone();
+
                 $copy.appendTo(codeContainer)
                     .bind('breakpoints-updated', dbg.breakpointsForPane);
 
+                // Make the code windows' fonts and spacing 80% of normal
+                $copy.css('font-size', '80%');
+                // Chop off the "px" from the end of the font-size and convert to int
+                var lineHeight = parseInt( $copy.css('line-height').slice(0,-2));
+                lineHeight = "" + (lineHeight * 0.8) + "px";
+                $copy.css('line-height', lineHeight);
+
                 dbg.setCurrentLineForCodeTable($copy, line);
                 dbg.breakpointManager.markBreakpoints(filename, $copy);
 
